# blueprint-workshop
[Official Documentation](https://blueprint-workshop.datarobot.com)

Construct, modify, and execute blueprints from the comfort, flexibility, and power of Python.

![Simple Example](./.github/Blueprint-Workshop-Preview.png)

### Prerequisites
- Ensure your DataRobot account has enabled:
  - `GRAYBOX_DISABLED` (Show Uncensored Blueprints)
  - `ENABLE_CUSTOMIZABLE_BLUEPRINTS` (Enable Customizable Blueprints)

### Installation
1. `mkvirtualenv -p python3.7 blueprint-workshop`
2. `sudo apt-get install graphviz` or `brew install graphviz`
3. `pip install datarobot-bp-workshop`

(Recommended):
1. `pip install jupyterlab`
2. From a folder where you'd like to save your scripts: `jupyter-lab .`


# Copyright and License

blueprint-workshop is Copyright 2021 DataRobot, Inc.  All rights reserved.

Licensed under a Modified 3-Clause BSD License (the "License"). See the License.txt file.  You may not use this software except in compliance with the License.
Software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES OF ANY KIND AND WITHOUT ANY LICENSE TO ANY PATENTS OR TRADEMARKS. See the License.txt file for the specific language governing permissions and limitations under the License
